@@ -32,10 +32,15 @@ from .pipeline import PMMLPipeline
 def _is_categorical(dtype):
 	if dtype == object or dtype == str or dtype == bool:
 		return True
-	elif hasattr(dtype, "name") and dtype.name == "category":
+	elif _is_pandas_categorical(dtype):
 		return True
 	return False
 
+def _is_pandas_categorical(dtype):
+	if hasattr(dtype, "name"):
+		return dtype.name == "category"
+	return False
+
 class EstimatorProxy(BaseEstimator):
 
 	def __init__(self, estimator, attr_names = ["feature_importances_"]):
@@ -140,22 +145,19 @@ def make_pmml_pipeline(obj, active_fields = None, target_fields = None):
 		pipeline.target_fields = numpy.asarray(target_fields)
 	return pipeline
 
-def _decode(data, encoding):
+def _java_version():
 	try:
-		return data.decode(encoding, errors = "ignore")
-	except ValueError:
-		return ""
-
-def _java_version(java_encoding):
-	try:
-		process = Popen(["java", "-version"], stdout = PIPE, stderr = PIPE, bufsize = 1)
+		process = Popen(["java", "-version"], stdout = PIPE, stderr = PIPE, bufsize = 1, universal_newlines = True)
 	except:
 		return None
 	output, error = process.communicate()
 	retcode = process.poll()
 	if retcode:
 		return None
-	match = re.match("^(.*)\sversion\s\"(.*)\"(|\s\d\d\d\d\-\d\d\-\d\d)$", _decode(error, java_encoding), re.MULTILINE)
+	return _parse_java_version(error)
+
+def _parse_java_version(java_version):
+	match = re.match("^(.*)\sversion\s\"(.*)\"(|\s.+)$", java_version, re.MULTILINE)
 	if match:
 		return (match.group(1), match.group(2))
 	else:
@@ -183,7 +185,7 @@ def _dump(obj, prefix):
 		os.close(fd)
 	return path
 
-def sklearn2pmml(pipeline, pmml, user_classpath = [], with_repr = False, debug = False, java_encoding = "UTF-8"):
+def sklearn2pmml(pipeline, pmml, user_classpath = [], with_repr = False, debug = False):
 	"""Converts a fitted PMML pipeline object to PMML file.
 
 	Parameters:
@@ -204,12 +206,9 @@ def sklearn2pmml(pipeline, pmml, user_classpath = [], with_repr = False, debug =
 	debug: boolean, optional
 		If true, print information about the conversion process.
 
-	java_encoding: string, optional
-		The character encoding to use for decoding Java output and error byte streams.
-
 	"""
 	if debug:
-		java_version = _java_version(java_encoding)
+		java_version = _java_version()
 		if java_version is None:
 			java_version = ("java", "N/A")
 		print("python: {0}".format(platform.python_version()))
@@ -230,9 +229,11 @@ def sklearn2pmml(pipeline, pmml, user_classpath = [], with_repr = False, debug =
 			pipeline.repr_ = repr(pipeline)
 		# if isinstance(estimator, H2OEstimator):
 		if hasattr(estimator, "download_mojo"):
-			estimator_mojo = estimator.download_mojo()
-			dumps.append(estimator_mojo)
-			estimator._mojo_path = estimator_mojo
+			# Avoid MOJO (re-)download if the indicator attribute is set
+			if not hasattr(estimator, "_mojo_path"):
+				estimator_mojo = estimator.download_mojo()
+				dumps.append(estimator_mojo)
+				estimator._mojo_path = estimator_mojo
 		pipeline_pkl = _dump(pipeline, "pipeline")
 		cmd.extend(["--pkl-pipeline-input", pipeline_pkl])
 		dumps.append(pipeline_pkl)
@@ -240,18 +241,18 @@ def sklearn2pmml(pipeline, pmml, user_classpath = [], with_repr = False, debug =
 		if debug:
 			print("Executing command:\n{0}".format(" ".join(cmd)))
 		try:
-			process = Popen(cmd, stdout = PIPE, stderr = PIPE, bufsize = 1)
+			process = Popen(cmd, stdout = PIPE, stderr = PIPE, bufsize = 1, universal_newlines = True)
 		except OSError:
 			raise RuntimeError("Java is not installed, or the Java executable is not on system path")
 		output, error = process.communicate()
 		retcode = process.poll()
 		if debug or retcode:
-			if(len(output) > 0):
-				print("Standard output:\n{0}".format(_decode(output, java_encoding)))
+			if len(output) > 0:
+				print("Standard output:\n{0}".format(output))
 			else:
 				print("Standard output is empty")
-			if(len(error) > 0):
-				print("Standard error:\n{0}".format(_decode(error, java_encoding)))
+			if len(error) > 0:
+				print("Standard error:\n{0}".format(error))
 			else:
 				print("Standard error is empty")
 		if retcode:
