@@ -1,4 +1,4 @@
-from pandas import Index, Series
+from pandas import Categorical, DataFrame, Index, Series
 from sklearn.base import clone, BaseEstimator, TransformerMixin
 
 import numpy
@@ -13,8 +13,37 @@ def cast(X, dtype):
 			X = numpy.asarray(X)
 		return X.astype(dtype)
 
+def common_dtype(X):
+	if hasattr(X, "dtype"):
+		return X.dtype
+	elif hasattr(X, "dtypes"):
+		dtypes = set(X.dtypes)
+		if len(dtypes) != 1:
+			raise ValueError(dtypes)
+		return next(iter(dtypes))
+	else:
+		raise ValueError()
+
+def ensure_1d(X):
+	if isinstance(X, (Categorical, Series)):
+		return X
+	elif isinstance(X, DataFrame):
+		columns = X.columns
+		if len(columns) == 1:
+			return X[columns[0]]
+	X = numpy.asarray(X)
+	shape = X.shape
+	if len(shape) == 1:
+		return X
+	elif (len(shape) == 2) and (shape[1] == 1):
+		return X.ravel()
+	else:
+		raise ValueError("Expected 1d array, got {}d array of shape {}".format(len(shape), str(shape)))
+
 def eval_rows(X, func, dtype = object):
 	if hasattr(X, "apply"):
+		if isinstance(X, Series):
+			return X.apply(func)
 		return X.apply(func, axis = 1)
 	nrow = X.shape[0]
 	Xt = numpy.empty(shape = (nrow, ), dtype = dtype)
